@@ -3,10 +3,10 @@ from typing import Optional
 from MSApi.Assortment import Assortment
 from MSApi.ObjectMS import check_init
 from MSApi.ProductFolder import ProductFolder
-from MSApi.mixin import AttributeMixin
+from MSApi.mixin import AttributeMixin, SalePricesMixin
 
 
-class Bundle(Assortment, AttributeMixin):
+class Bundle(Assortment, AttributeMixin, SalePricesMixin):
 
     _type_name = 'bundle'
 
