@@ -35,7 +35,7 @@ class Processing(DocumentMS):
         super().__init__(json)
 
     def create(self, **kwargs):
-        response = MSLowApi.auch_post(f'entity/demand', json=self.get_json(), **kwargs)
+        response = MSLowApi.auch_post(f'entity/processing', json=self.get_json(), **kwargs)
         error_handler(response)
         self._json = response.json()
 
