@@ -40,7 +40,9 @@ class Filter(object):
     @classmethod
     def exists(cls, parameter, exists=True):
         operator = '!=' if exists else '='
-        return Filter().filters.append(f"{parameter}{operator}")
+        f = Filter()
+        f.filters.append(f"{parameter}{operator}")
+        return f
 
     def __init__(self):
         self.filters = []
